@@ -10,7 +10,7 @@ use Carp;
 use English qw( -no_match_vars ) ;
 
 use parent 'Exporter';
-use Zonemaster::Engine::Net::IP;
+use Net::IP::XS;
 use Text::CSV;
 use File::ShareDir qw[dist_dir dist_file];
 
@@ -25,21 +25,23 @@ our @EXPORT_OK = qw[
   $ALGO_STATUS_NOT_RECOMMENDED
   $ALGO_STATUS_NOT_ZONE_SIGN
   $BLACKLISTING_ENABLED
+  $DURATION_5_MINUTES_IN_SECONDS
+  $DURATION_1_HOUR_IN_SECONDS
+  $DURATION_4_HOURS_IN_SECONDS
   $DURATION_12_HOURS_IN_SECONDS
+  $DURATION_1_DAY_IN_SECONDS
+  $DURATION_1_WEEK_IN_SECONDS
   $DURATION_180_DAYS_IN_SECONDS
   $FQDN_MAX_LENGTH
   $IP_VERSION_4
   $IP_VERSION_6
   $LABEL_MAX_LENGTH
-  $MAX_SERIAL_VARIATION
+  $SERIAL_BITS
+  $SERIAL_MAX_VARIATION
   $MINIMUM_NUMBER_OF_NAMESERVERS
   $RESOLVER_SOURCE_OS_DEFAULT
-  $SOA_DEFAULT_TTL_MAXIMUM_VALUE
-  $SOA_DEFAULT_TTL_MINIMUM_VALUE
-  $SOA_EXPIRE_MINIMUM_VALUE
-  $SOA_REFRESH_MINIMUM_VALUE
-  $SOA_RETRY_MINIMUM_VALUE
   $UDP_PAYLOAD_LIMIT
+  $UDP_EDNS_QUERY_DEFAULT
   $UDP_COMMON_EDNS_LIMIT
   @IPV4_SPECIAL_ADDRESSES
   @IPV6_SPECIAL_ADDRESSES
@@ -53,9 +55,9 @@ our %EXPORT_TAGS = (
     name => [qw($FQDN_MAX_LENGTH $LABEL_MAX_LENGTH)],
     ip   => [qw($IP_VERSION_4 $IP_VERSION_6)],
     soa  => [
-        qw($SOA_DEFAULT_TTL_MAXIMUM_VALUE $SOA_DEFAULT_TTL_MINIMUM_VALUE $SOA_EXPIRE_MINIMUM_VALUE $SOA_REFRESH_MINIMUM_VALUE $SOA_RETRY_MINIMUM_VALUE $DURATION_12_HOURS_IN_SECONDS $DURATION_180_DAYS_IN_SECONDS $MAX_SERIAL_VARIATION)
+        qw($DURATION_5_MINUTES_IN_SECONDS $DURATION_1_HOUR_IN_SECONDS $DURATION_4_HOURS_IN_SECONDS $DURATION_12_HOURS_IN_SECONDS $DURATION_1_DAY_IN_SECONDS $DURATION_1_WEEK_IN_SECONDS $DURATION_180_DAYS_IN_SECONDS $SERIAL_BITS $SERIAL_MAX_VARIATION)
     ],
-    misc => [qw($UDP_PAYLOAD_LIMIT $UDP_COMMON_EDNS_LIMIT $MINIMUM_NUMBER_OF_NAMESERVERS $RESOLVER_SOURCE_OS_DEFAULT $BLACKLISTING_ENABLED)]
+    misc => [qw($UDP_PAYLOAD_LIMIT $UDP_EDNS_QUERY_DEFAULT $UDP_COMMON_EDNS_LIMIT $MINIMUM_NUMBER_OF_NAMESERVERS $RESOLVER_SOURCE_OS_DEFAULT $BLACKLISTING_ENABLED)]
     ,    # everyting in %EXPORT_OK that isn't included in any of the other tags
     addresses => [qw(@IPV4_SPECIAL_ADDRESSES @IPV6_SPECIAL_ADDRESSES)],
 );
@@ -70,8 +72,13 @@ Readonly our $ALGO_STATUS_NOT_RECOMMENDED => 9;
 
 Readonly our $BLACKLISTING_ENABLED     => 1;
 
-Readonly our $DURATION_12_HOURS_IN_SECONDS => 12 * 60 * 60;
-Readonly our $DURATION_180_DAYS_IN_SECONDS => 180 * 24 * 60 * 60;
+Readonly our $DURATION_5_MINUTES_IN_SECONDS  =>             5 * 60;
+Readonly our $DURATION_1_HOUR_IN_SECONDS     =>            60 * 60;
+Readonly our $DURATION_4_HOURS_IN_SECONDS    =>        4 * 60 * 60;
+Readonly our $DURATION_12_HOURS_IN_SECONDS   =>       12 * 60 * 60;
+Readonly our $DURATION_1_DAY_IN_SECONDS      =>       24 * 60 * 60;
+Readonly our $DURATION_1_WEEK_IN_SECONDS     =>   7 * 24 * 60 * 60;
+Readonly our $DURATION_180_DAYS_IN_SECONDS   => 180 * 24 * 60 * 60;
 
 # Maximum length of ASCII version of a domain name, with trailing dot.
 Readonly our $FQDN_MAX_LENGTH  => 254;
@@ -80,20 +87,16 @@ Readonly our $LABEL_MAX_LENGTH => 63;
 Readonly our $IP_VERSION_4 => 4;
 Readonly our $IP_VERSION_6 => 6;
 
-Readonly our $MAX_SERIAL_VARIATION => 0;
-
 Readonly our $MINIMUM_NUMBER_OF_NAMESERVERS => 2;
 
 Readonly our $RESOLVER_SOURCE_OS_DEFAULT => 'os_default';
 
-Readonly our $SOA_DEFAULT_TTL_MAXIMUM_VALUE => 86_400;     # 1 day
-Readonly our $SOA_DEFAULT_TTL_MINIMUM_VALUE => 300;        # 5 minutes
-Readonly our $SOA_EXPIRE_MINIMUM_VALUE      => 604_800;    # 1 week
-Readonly our $SOA_REFRESH_MINIMUM_VALUE     => 14_400;     # 4 hours
-Readonly our $SOA_RETRY_MINIMUM_VALUE       => 3_600;      # 1 hour
+Readonly our $SERIAL_BITS => 32;
+Readonly our $SERIAL_MAX_VARIATION => 0;
 
-Readonly our $UDP_PAYLOAD_LIMIT     => 512;
-Readonly our $UDP_COMMON_EDNS_LIMIT => 4_096;
+Readonly our $UDP_PAYLOAD_LIMIT      => 512;
+Readonly our $UDP_EDNS_QUERY_DEFAULT => 512;
+Readonly our $UDP_COMMON_EDNS_LIMIT  => 4_096;
 
 Readonly::Array our @IPV4_SPECIAL_ADDRESSES => _extract_iana_ip_blocks($IP_VERSION_4);
 
@@ -128,7 +131,7 @@ sub _extract_iana_ip_blocks {
             $address_data =~ s/[ ]+//smx;
             foreach my $address_item ( split /,/smx, $address_data ) {
                 $address_item =~ s/(\A.+\/\d+).*\z/$1/smx;
-                push @list, { ip => Zonemaster::Engine::Net::IP->new( $address_item ), name => $fields->[1], reference => $fields->[2] };
+                push @list, { ip => Net::IP::XS->new( $address_item ), name => $fields->[1], reference => $fields->[2] };
             }
         }
         close $data or croak "Cannot close '${data_location}' : ${OS_ERROR}";
@@ -219,10 +222,30 @@ C<$ALGO_STATUS_NOT_ZONE_SIGN>
 
 =item *
 
+C<$DURATION_5_MINUTES_IN_SECONDS>
+
+=item *
+
+C<$DURATION_1_HOUR_IN_SECONDS>
+
+=item *
+
+C<$DURATION_4_HOURS_IN_SECONDS>
+
+=item *
+
 C<$DURATION_12_HOURS_IN_SECONDS>
 
 =item *
 
+C<$DURATION_1_DAY_IN_SECONDS>
+
+=item *
+
+C<$DURATION_1_WEEK_IN_SECONDS>
+
+=item *
+
 C<$DURATION_180_DAYS_IN_SECONDS>
 
 =item *
@@ -243,7 +266,13 @@ C<$IP_VERSION_6>
 
 =item *
 
-C<$MAX_SERIAL_VARIATION>
+C<$SERIAL_BITS>
+
+An integer, used to define the size of the serial number space, as defined in RFC1982, section 2.
+
+=item *
+
+C<$SERIAL_MAX_VARIATION>
 
 =item *
 
@@ -251,30 +280,16 @@ C<$MINIMUM_NUMBER_OF_NAMESERVERS>
 
 =item *
 
-C<$SOA_DEFAULT_TTL_MAXIMUM_VALUE>
-
-=item *
-
-C<$SOA_DEFAULT_TTL_MINIMUM_VALUE>
-
-=item *
-
-C<$SOA_EXPIRE_MINIMUM_VALUE>
-
-=item *
-
-C<$SOA_REFRESH_MINIMUM_VALUE>
-
-=item *
-
-C<$SOA_RETRY_MINIMUM_VALUE>
-
-=item *
-
 C<$UDP_PAYLOAD_LIMIT>
 
 =item *
 
+C<$UDP_EDNS_QUERY_DEFAULT>
+
+An integer, used to define the EDNS0 UDP packet size in EDNS queries.
+
+=item *
+
 C<UDP_COMMON_EDNS_LIMIT>
 
 =item *
