@@ -1,16 +1,21 @@
 package Zonemaster::Engine::Logger;
 
-use version; our $VERSION = version->declare("v1.0.7");
-
 use 5.014002;
+
+use strict;
+use warnings;
+
+use version; our $VERSION = version->declare("v1.0.8");
+
 use Moose;
 
-use Zonemaster::Engine::Logger::Entry;
-use Zonemaster::Engine;
 use List::MoreUtils qw[none any];
 use Scalar::Util qw[blessed];
 use JSON::PP;
 
+use Zonemaster::Engine::Profile;
+use Zonemaster::Engine::Logger::Entry;
+
 has 'entries' => (
     is      => 'ro',
     isa     => 'ArrayRef[Zonemaster::Engine::Logger::Entry]',
@@ -18,6 +23,8 @@ has 'entries' => (
 );
 has 'callback' => ( is => 'rw', isa => 'CodeRef', required => 0, clearer => 'clear_callback' );
 
+my $logfilter;
+
 sub add {
     my ( $self, $tag, $argref ) = @_;
 
@@ -45,17 +52,18 @@ sub add {
 
 sub _check_filter {
     my ( $self, $entry ) = @_;
-    my $config = Zonemaster::Engine::Profile->effective->get(q{logfilter});
 
-    if ( $config ) {
-        if ( $config->{ $entry->module } ) {
+    if ( ! defined $logfilter ) {
+        $logfilter = Zonemaster::Engine::Profile->effective->get(q{logfilter});
+    }
+
+    if ( $logfilter ) {
+        if ( $logfilter->{ $entry->module } ) {
             my $match = 0;
-            foreach my $rule ( @{$config->{ $entry->module }{ $entry->tag }} ) {
+            foreach my $rule ( @{$logfilter->{ $entry->module }{ $entry->tag }} ) {
                 foreach my $key ( keys %{ $rule->{when} } ) {
                     my $cond = $rule->{when}{$key};
                     if ( ref( $cond ) and ref( $cond ) eq 'ARRAY' ) {
-                        ## no critic (TestingAndDebugging::ProhibitNoWarnings)
-                        # no warnings 'uninitialized';
                         if ( any { $_ eq $entry->args->{$key} } @$cond ) {
                             $match = 1;
                         } else {
@@ -64,8 +72,6 @@ sub _check_filter {
                         }
                     }
                     else {
-                        ## no critic (TestingAndDebugging::ProhibitNoWarnings)
-                        # no warnings 'uninitialized';
                         if ( $cond eq $entry->args->{$key} ) {
                             $match = 1;
                         } else {
@@ -79,8 +85,9 @@ sub _check_filter {
                     last;
                 }
             }
-        } ## end if ( $config->{ $entry...})
-    } ## end if ( $config )
+        }
+    }
+    return;
 } ## end sub _check_filter
 
 sub start_time_now {
@@ -88,6 +95,12 @@ sub start_time_now {
     return;
 }
 
+sub reset_config {
+    $logfilter = undef;
+    Zonemaster::Engine::Logger::Entry->reset_config();
+    return;
+}
+
 sub clear_history {
     my ( $self ) = @_;
 
@@ -127,6 +140,7 @@ sub json {
         my %r;
         $r{timestamp} = $m->timestamp;
         $r{module}    = $m->module;
+        $r{testcase}  = $m->testcase;
         $r{tag}       = $m->tag;
         $r{level}     = $m->level;
         $r{args}      = $m->args if $m->args;
@@ -208,6 +222,21 @@ Set the logger's start time to the current time.
 
 Remove all known log entries.
 
+=item reset_config()
+
+Clear the test level cached configuration.
+
+=back
+
+=head1 SUBROUTINES
+
+=over
+
+=item _check_filter($entry)
+
+Apply the C<logfilter> defined rules to the entry. See
+L<Zonemaster::Engine::Profile/"logfilter">.
+
 =back
 
 =cut
