@@ -136,6 +136,30 @@ sub metadata {
 } ## end sub metadata
 
 Readonly my %TAG_DESCRIPTIONS => (
+    CONSISTENCY01 => sub {
+        __x    # CONSISTENCY:CONSISTENCY01
+          'SOA serial number consistency';
+    },
+    CONSISTENCY02 => sub {
+        __x    # CONSISTENCY:CONSISTENCY02
+          'SOA RNAME consistency';
+    },
+    CONSISTENCY03 => sub {
+        __x    # CONSISTENCY:CONSISTENCY03
+          'SOA timers consistency';
+    },
+    CONSISTENCY04 => sub {
+        __x    # CONSISTENCY:CONSISTENCY04
+          'Name server NS consistency';
+    },
+    CONSISTENCY05 => sub {
+        __x    # CONSISTENCY:CONSISTENCY05
+          'Consistency between glue and authoritative data';
+    },
+    CONSISTENCY06 => sub {
+        __x    # CONSISTENCY:CONSISTENCY06
+          'SOA MNAME consistency';
+    },
     ADDRESSES_MATCH => sub {
         __x    # CONSISTENCY:ADDRESSES_MATCH
           'Glue records are consistent between glue and authoritative data.', @_;
@@ -266,6 +290,35 @@ sub version {
     return "$Zonemaster::Engine::Test::Consistency::VERSION";
 }
 
+sub _ip_disabled_message {
+    my ( $results_array, $ns, @rrtypes ) = @_;
+
+    if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) and $ns->address->version == $IP_VERSION_6 ) {
+        push @$results_array, map {
+          info(
+            IPV6_DISABLED => {
+                ns     => $ns->string,
+                rrtype => $_
+            }
+          )
+        } @rrtypes;
+        return 1;
+    }
+
+    if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) and $ns->address->version == $IP_VERSION_4 ) {
+        push @$results_array, map {
+          info(
+            IPV4_DISABLED => {
+                ns     => $ns->string,
+                rrtype => $_,
+            }
+          )
+        } @rrtypes;
+        return 1;
+    }
+    return 0;
+}
+
 ###
 ### Tests
 ###
@@ -283,25 +336,7 @@ sub consistency01 {
 
         next if $nsnames_and_ip{ $local_ns->name->string . q{/} . $local_ns->address->short };
 
-        if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) and $local_ns->address->version == $IP_VERSION_6 ) {
-            push @results,
-              info(
-                IPV6_DISABLED => {
-                    ns     => $local_ns->string,
-                    rrtype => $query_type,
-                }
-              );
-            next;
-        }
-
-        if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) and $local_ns->address->version == $IP_VERSION_4 ) {
-            push @results,
-              info(
-                IPV4_DISABLED => {
-                    ns     => $local_ns->string,
-                    rrtype => $query_type,
-                }
-              );
+        if ( _ip_disabled_message( \@results, $local_ns, $query_type ) ) {
             next;
         }
 
@@ -351,13 +386,13 @@ sub consistency01 {
                 count => scalar( keys %serials ),
             }
           );
-        if ( $serial_numbers[-1] - $serial_numbers[0] > $MAX_SERIAL_VARIATION ) {
+        if ( $serial_numbers[-1] - $serial_numbers[0] > $SERIAL_MAX_VARIATION ) {
             push @results,
               info(
                 SOA_SERIAL_VARIATION => {
                     serial_min    => $serial_numbers[0],
                     serial_max    => $serial_numbers[-1],
-                    max_variation => $MAX_SERIAL_VARIATION,
+                    max_variation => $SERIAL_MAX_VARIATION,
                 }
               );
         }
@@ -379,25 +414,7 @@ sub consistency02 {
 
         next if $nsnames_and_ip{ $local_ns->name->string . q{/} . $local_ns->address->short };
 
-        if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) and $local_ns->address->version == $IP_VERSION_6 ) {
-            push @results,
-              info(
-                IPV6_DISABLED => {
-                    ns     => $local_ns->string,
-                    rrtype => $query_type,
-                }
-              );
-            next;
-        }
-
-        if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) and $local_ns->address->version == $IP_VERSION_4 ) {
-            push @results,
-              info(
-                IPV4_DISABLED => {
-                    ns     => $local_ns->string,
-                    rrtype => $query_type,
-                }
-              );
+        if ( _ip_disabled_message( \@results, $local_ns, $query_type ) ) {
             next;
         }
 
@@ -462,25 +479,7 @@ sub consistency03 {
 
         next if $nsnames_and_ip{ $local_ns->name->string . q{/} . $local_ns->address->short };
 
-        if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) and $local_ns->address->version == $IP_VERSION_6 ) {
-            push @results,
-              info(
-                IPV6_DISABLED => {
-                    ns     => $local_ns->string,
-                    rrtype => $query_type,
-                }
-              );
-            next;
-        }
-
-        if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) and $local_ns->address->version == $IP_VERSION_4 ) {
-            push @results,
-              info(
-                IPV4_DISABLED => {
-                    ns     => $local_ns->string,
-                    rrtype => $query_type,
-                }
-              );
+        if ( _ip_disabled_message( \@results, $local_ns, $query_type ) ) {
             next;
         }
 
@@ -556,25 +555,7 @@ sub consistency04 {
 
         next if $nsnames_and_ip{ $local_ns->name->string . q{/} . $local_ns->address->short };
 
-        if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) and $local_ns->address->version == $IP_VERSION_6 ) {
-            push @results,
-              info(
-                IPV6_DISABLED => {
-                    ns     => $local_ns->string,
-                    rrtype => $query_type,
-                }
-              );
-            next;
-        }
-
-        if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) and $local_ns->address->version == $IP_VERSION_4 ) {
-            push @results,
-              info(
-                IPV4_DISABLED => {
-                    ns     => $local_ns->string,
-                    rrtype => $query_type,
-                }
-              );
+        if ( _ip_disabled_message( \@results, $local_ns, $query_type ) ) {
             next;
         }
 
@@ -795,25 +776,7 @@ sub consistency06 {
 
         next if $nsnames_and_ip{ $local_ns->name->string . q{/} . $local_ns->address->short };
 
-        if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) and $local_ns->address->version == $IP_VERSION_6 ) {
-            push @results,
-              info(
-                IPV6_DISABLED => {
-                    ns     => $local_ns->string,
-                    rrtype => $query_type,
-                }
-              );
-            next;
-        }
-
-        if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) and $local_ns->address->version == $IP_VERSION_4 ) {
-            push @results,
-              info(
-                IPV4_DISABLED => {
-                    ns     => $local_ns->string,
-                    rrtype => $query_type,
-                }
-              );
+        if ( _ip_disabled_message( \@results, $local_ns, $query_type ) ) {
             next;
         }
 
